==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tetopologiesaugment/te/templates/DefaultNodeTemplate.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tetopologiesaugment.te.templates;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeTemplateName;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.templateattributes.ReferenceChangePolicyEnum;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeconfigattributestemplate.TeNodeAttributes;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of nodeTemplate.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultNodeTemplate extends InnerModelObject 
        implements NodeTemplate, MultiInstanceObject<NodeTemplateKeys> {
    protected TeTemplateName name;
    protected int priority;
    protected ReferenceChangePolicyEnum referenceChangePolicy;
    protected BitSet valueLeafFlags = new BitSet();
    protected TeNodeAttributes teNodeAttributes;

    @Override
    public TeTemplateName name() {
        return name;
    }

    @Override
    public int priority() {
        return priority;
    }

    @Override
    public ReferenceChangePolicyEnum referenceChangePolicy() {
        return referenceChangePolicy;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public TeNodeAttributes teNodeAttributes() {
        return teNodeAttributes;
    }

    @Override
    public void name(TeTemplateName name) {
        valueLeafFlags.set(LeafIdentifier.NAME.getLeafIndex());
        this.name = name;
    }

    @Override
    public void priority(int priority) {
        valueLeafFlags.set(LeafIdentifier.PRIORITY.getLeafIndex());
        this.priority = priority;
    }

    @Override
    public void referenceChangePolicy(ReferenceChangePolicyEnum referenceChangePolicy) {
        valueLeafFlags.set(LeafIdentifier.REFERENCECHANGEPOLICY.getLeafIndex());
        this.referenceChangePolicy = referenceChangePolicy;
    }

    @Override
    public void teNodeAttributes(TeNodeAttributes teNodeAttributes) {
        this.teNodeAttributes = teNodeAttributes;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, priority, referenceChangePolicy, valueLeafFlags, teNodeAttributes);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultNodeTemplate) {
            DefaultNodeTemplate other = (DefaultNodeTemplate) obj;
            return
                Objects.equals(name, other.name) &&
                Objects.equals(priority, other.priority) &&
                Objects.equals(referenceChangePolicy, other.referenceChangePolicy) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(teNodeAttributes, other.teNodeAttributes);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("name=" + name)
            .add("priority=" + priority)
            .add("referenceChangePolicy=" + referenceChangePolicy)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("teNodeAttributes=" + teNodeAttributes)
            .toString();
    }


    /**
     * Creates an instance of defaultNodeTemplate.
     */
    public DefaultNodeTemplate() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tetopologiesaugment/te/templates/DefaultNodeTemplate.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tetopologiesaugment.te.templates;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeTemplateName;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.templateattributes.ReferenceChangePolicyEnum;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeconfigattributestemplate.TeNodeAttributes;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of nodeTemplate.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultNodeTemplate extends InnerModelObject 
        implements NodeTemplate, MultiInstanceObject<NodeTemplateKeys> {
    protected TeTemplateName name;
    protected int priority;
    protected ReferenceChangePolicyEnum referenceChangePolicy;
    protected BitSet valueLeafFlags = new BitSet();
    protected TeNodeAttributes teNodeAttributes;

    @Override
    public TeTemplateName name() {
        return name;
    }

    @Override
    public int priority() {
        return priority;
    }

    @Override
    public ReferenceChangePolicyEnum referenceChangePolicy() {
        return referenceChangePolicy;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public TeNodeAttributes teNodeAttributes() {
        return teNodeAttributes;
    }

    @Override
    public void name(TeTemplateName name) {
        valueLeafFlags.set(LeafIdentifier.NAME.getLeafIndex());
        this.name = name;
    }

    @Override
    public void priority(int priority) {
        valueLeafFlags.set(LeafIdentifier.PRIORITY.getLeafIndex());
        this.priority = priority;
    }

    @Override
    public void referenceChangePolicy(ReferenceChangePolicyEnum referenceChangePolicy) {
        valueLeafFlags.set(LeafIdentifier.REFERENCECHANGEPOLICY.getLeafIndex());
        this.referenceChangePolicy = referenceChangePolicy;
    }

    @Override
    public void teNodeAttributes(TeNodeAttributes teNodeAttributes) {
        this.teNodeAttributes = teNodeAttributes;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, priority, referenceChangePolicy, valueLeafFlags, teNodeAttributes);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultNodeTemplate) {
            DefaultNodeTemplate other = (DefaultNodeTemplate) obj;
            return
                Objects.deepEquals(name, other.name) &&
                Objects.deepEquals(priority, other.priority) &&
                Objects.deepEquals(referenceChangePolicy, other.referenceChangePolicy) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(teNodeAttributes, other.teNodeAttributes);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("name=" + name)
            .add("priority=" + priority)
            .add("referenceChangePolicy=" + referenceChangePolicy)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("teNodeAttributes=" + teNodeAttributes)
            .toString();
    }


    /**
     * Creates an instance of defaultNodeTemplate.
     */
    public DefaultNodeTemplate() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
